pigz version 2.4
diff --git a/README b/README
index 5cd1682..da89431 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-pigz 2.3.5 (xx Dec 2017) by Mark Adler
+pigz 2.4 (26 Dec 2017) by Mark Adler
 
 pigz, which stands for Parallel Implementation of GZip, is a fully functional
 replacement for gzip that exploits multiple processors and multiple cores to
diff --git a/pigz.1 b/pigz.1
index 33ff46c..49a46af 100644
--- a/pigz.1
+++ b/pigz.1
@@ -1,4 +1,4 @@
-.TH PIGZ 1 "December xx, 2017"
+.TH PIGZ 1 "December 26, 2017"
 .SH NAME
 pigz, unpigz \- compress or expand files
 .SH SYNOPSIS
diff --git a/pigz.pdf b/pigz.pdf
index 086a186..3ff626d 100644
--- a/pigz.pdf
+++ b/pigz.pdf
Binary files differ
diff --git a/pigz.spec b/pigz.spec
index 8ede8e9..9d31cb0 100644
--- a/pigz.spec
+++ b/pigz.spec
@@ -1,6 +1,6 @@
 Summary: pigz is a parallel implementation of gzip which utilizes multiple cores
 Name: pigz
-Version: 2.3.5
+Version: 2.4
 Release: 1
 Source0: %{name}-%{version}.tar.gz
 License: zlib
diff --git a/pigz.c b/pigz.c
index 04b5431..bbbfd2c 100644
--- a/pigz.c
+++ b/pigz.c
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
  * Copyright (C) 2007-2017 Mark Adler
  * Version 2.3.5  xx Dec 2017  Mark Adler
  */
 
 /*
@@ -175,10 +175,20 @@
                        Permit named pipes as input (e.g. made by mkfifo())
                        Fix a bug in -r directory traversal
                        Add warning for a zip file entry 4 GiB or larger
-   2.3.5  xx Dec 2017  -
+   2.4    26 Dec 2017  Portability improvements
+                       Produce Zip64 format when needed for --zip (>= 4 GiB)
+                       Make -no-name compatible with gzip, add --time option
+                       Add -m as a short option for --no-time
+                       Check run-time zlib version to handle weak linking
+                       Fix a concurrent read bug in --list operation
+                       Process options first, for gzip compatibility
+                       Add --synchronous (-Y) option to force device write
+                       Disallow an empty suffix (e.g. --suffix '')
+                       Return an exit code of 1 if any issues are encountered
+                       Fix sign error in compression reduction percentage
  */
 
-#define VERSION "pigz 2.3.5x\n"
+#define VERSION "pigz 2.4\n"
 
 /* To-do:
     - make source portable for Windows, VMS, etc. (see gzip source code)
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
  * Copyright (C) 2007-2017 Mark Adler
- * Version 2.3.5  xx Dec 2017  Mark Adler
+ * Version 2.4  26 Dec 2017  Mark Adler
  */
 